import polars as pl
import io


def obfuscate_json_file(json_file_object,
                        columns_for_obfuscation,
                        replacement_string):
    """
    For a single JSON file object input, replaces all values in
    specified columns with a single replacement string value,
    and returns bytes object of transformed JSON data

    Args:
        json_file_object: target JSON file object
        columns_for_obfuscation: list of target columns
        replacement_string: string to be used to replace
                              target column values
    Returns:
        BytesIO data object
    """
    try:
        json_obfuscation_operation = (
            pl.read_json(json_file_object.read()).lazy()
            .with_columns(pl.col(columns_for_obfuscation)
                          .str.replace_all(r"(?s).*", replacement_string))
        )
        obfuscated_json_df = json_obfuscation_operation.collect()

        buffer = io.BytesIO()
        obfuscated_json_df.write_json(buffer)
        buffer.seek(0)

        return buffer

    except Exception as e:
        print(f'Failed to generate BytesIO object from JSON file: {e}')



import json


def get_columns_to_be_obfuscated(input_json, restricted_fields):
    """
    Extracts names of fields to be obfuscated,
    from "pii_fields" field in input JSON string

    Args:
        input_json: target JSON string
        restricted_fields: list of fields that cannot be overwritten,
                regardless of contents of input_json (default = [])

    Returns:
        List of field names
    """
    try:
        input_params = json.loads(input_json)

        columns_for_obfuscation = input_params["pii_fields"]
        columns_to_be_obfuscated = ([column for column
                                    in columns_for_obfuscation
                                    if column not in restricted_fields])

        return columns_to_be_obfuscated

    except Exception as e:
        print(
            f"Could not extract columns to be obfuscated from JSON input: {e}")
